import PropTypes from "prop-types";
import cn from "classnames";
import styles from "./styles.module.css";

const Button = ({ children, isDisabled, variant, className, ...props }) => {
  const classNames = cn(styles["btn"], {
    [styles[variant]]: variant,
    [styles[className]]: className,
    [styles.disabled]: isDisabled === true,
  });

  return (
    <button className={`${classNames}`} {...props} disabled={isDisabled}>
      {children}
    </button>
  );
};

Button.propTypes = {
  variant: PropTypes.oneOf(["primary", "secondary"]),
  children: PropTypes.any,
  isDisabled: PropTypes.bool,
};

export default Button;
