"use client";
import React, { useState } from "react";
import PropTypes from "prop-types";
import Card from "@components/base/card";
import Pagination from "@components/top-level/pagination";
import styles from "./styles.module.css";

const BlogLists = ({ title, description, blogs }) => {
  const length = blogs.length;
  const itemsPerPage = 6;
  const [currentPage, setCurrentPage] = useState(1);

  // Calculate the start and end indices for the current page
  const startIndex = (currentPage - 1) * itemsPerPage;
  const endIndex = startIndex + itemsPerPage;
  const slicedData = blogs.slice(startIndex, endIndex);

  // Handle page change
  const handlePageChange = (pageNumber) => {
    setCurrentPage(pageNumber);
    window.scrollTo({ top: 0, behavior: "smooth" });
  };

  return (
    <div className={styles["blog-container"]}>
      <h1 className={styles.title}>{title}</h1>
      <p className={styles.description}>{description}</p>
      <div className={styles.row}>
        {slicedData.map((blogData, i) => (
          <div key={i} className={styles.col}>
            <Card {...blogData} />
          </div>
        ))}
      </div>
      <div className={styles.pagination}>
        <Pagination
          currentPage={currentPage}
          total={length}
          perPage={itemsPerPage}
          onPageChange={handlePageChange}
        />
      </div>
    </div>
  );
};

BlogLists.propTypes = {
  title: PropTypes.string,
  description: PropTypes.string,
  blogs: PropTypes.array,
};

export default BlogLists;
