import PropTypes from "prop-types";
import Image from "next/image";
import ReactMarkdown from "react-markdown";
import rehypeRaw from "rehype-raw";
import styles from "./styles.module.css";
function SingleBlog({
  title,
  publishedDate,
  author,
  blogImage,
  category,
  readingTime,
  categories,
  markdown,
}) {
  return (
    <>
      <div className={styles["head-container"]}>
        <div className={styles.headtitle}>
          <h1 className={styles.title}>{title}</h1>
        </div>
        <div className={styles["blog-list"]}>
          <ul>
            <li>
              Posted on&nbsp;
              <span className={styles["list-bold"]}>{publishedDate}</span>
            </li>
            <li>
              By&nbsp;
              <a href="#" className={styles["list-bold"]}>
                {author.name}
              </a>
            </li>
            <li>
              Published in&nbsp;
              <a href="#" className={styles["list-bold"]}>
                {category}
              </a>
            </li>
            <li>
              <a href="#" className={styles["list-bold"]}>
                {readingTime}
              </a>
            </li>
          </ul>
        </div>
      </div>
      <div className={styles["blog-container"]}>
        <div className={styles.blogimage}>
          <Image
            className={styles.img}
            src={blogImage.url}
            alt={author.name}
            width={blogImage.width}
            height={blogImage.height}
          />
        </div>
        <div className={styles["blog-content"]}>
          <ReactMarkdown rehypePlugins={[rehypeRaw]}>{markdown}</ReactMarkdown>
          <div className={styles.tag}>
            <span>Tags:</span>
            {categories.map((e, i) => (
              <p key={i}>{e}</p>
            ))}
          </div>
        </div>
      </div>
    </>
  );
}

SingleBlog.propTypes = {
  title: PropTypes.string,
  publishedDate: PropTypes.string,
  author: {
    name: PropTypes.string,
  },
  blogImage: PropTypes.shape({
    url: PropTypes.string,
    width: PropTypes.number,
    height: PropTypes.number,
  }),
  category: PropTypes.string,
  readingTime: PropTypes.string,
  categories: PropTypes.array,
  markdown: PropTypes.any,
};
export default SingleBlog;
